
# Slot: files




URI: [https://w3id.org/neat/fileResourceContainer__files](https://w3id.org/neat/fileResourceContainer__files)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [FileResource](FileResource.md)

## Parents


## Children


## Used by

 * [FileResourceContainer](FileResourceContainer.md)
